@@ -5,9 +5,10 @@
 # License: MIT (see COPYING.MIT file)
 
 import numpy as np
-import _imread
 
-from special import special
+from . import _imread
+
+from .special import special
 
 def _parse_formatstr(filename, formatstr, funcname):
     if formatstr is not None:
@@ -15,7 +16,7 @@ def _parse_formatstr(filename, formatstr, funcname):
     from os import path
     _,ext = path.splitext(filename)
     if len(ext) and ext[0] == '.':
-        return ext[1:]
+        return ext[1:].lower()
     raise ValueError('imread.%s: Could not identify format from filename: `%s`' % (funcname,filename))
 
 def imread(filename, as_grey=False, formatstr=None):
