@@ -7,6 +7,10 @@ def test_with_dot():
     f = imread('./imread/tests/data/good.png')
     assert f.shape == (2,2)
 
+def test_uppercase():
+    f = imread('./imread/tests/data/GOOD.PNG')
+    assert f.shape == (2,2)
+
 @raises(ValueError)
 def test_no_ext():
     imread('file_without_extension')
